summary refs log tree commit diff
path: root/src/libnm-client-impl
diff options
context:
space:
mode:
authorMichael Biebl <biebl@debian.org>2024-08-09 18:57:15 +0200
committerMichael Biebl <biebl@debian.org>2024-08-09 18:57:15 +0200
commite96d74409128c6a977e31f24fad9b267d2feb9a1 (patch)
tree12dad71135c6c291de457568cb973208ea8a0024 /src/libnm-client-impl
parent45a364c60a9d6d34e614c4f1f507c69336ad1e69 (diff)
New upstream version 1.48.8 upstream/1.48.8
Diffstat (limited to 'src/libnm-client-impl')
-rw-r--r--src/libnm-client-impl/nm-active-connection.c6
-rw-r--r--src/libnm-client-impl/nm-client.c6
-rw-r--r--src/libnm-client-impl/nm-device-bond.c8
-rw-r--r--src/libnm-client-impl/nm-device-bridge.c8
-rw-r--r--src/libnm-client-impl/nm-device-ovs-bridge.c8
-rw-r--r--src/libnm-client-impl/nm-device-ovs-port.c8
-rw-r--r--src/libnm-client-impl/nm-device-team.c10
-rw-r--r--src/libnm-client-impl/nm-device.c6
-rw-r--r--src/libnm-client-impl/nm-libnm-utils.h2
9 files changed, 31 insertions, 31 deletions
diff --git a/src/libnm-client-impl/nm-active-connection.c b/src/libnm-client-impl/nm-active-connection.c
index 6a138f3e..0d186361 100644
--- a/src/libnm-client-impl/nm-active-connection.c
+++ b/src/libnm-client-impl/nm-active-connection.c
@@ -381,9 +381,9 @@ nm_active_connection_get_vpn(NMActiveConnection *connection)
  * nm_active_connection_get_master:
  * @connection: a #NMActiveConnection
  *
- * Gets the master #NMDevice of the connection.
+ * Gets the controller #NMDevice of the connection.
  *
- * Returns: (transfer none): the master #NMDevice of the #NMActiveConnection.
+ * Returns: (transfer none): the controller #NMDevice of the #NMActiveConnection.
  *
  * Deprecated: 1.44: Use nm_active_connection_get_controller() instead.
  **/
@@ -880,7 +880,7 @@ nm_active_connection_class_init(NMActiveConnectionClass *klass)
     /**
      * NMActiveConnection:master:
      *
-     * The master device if one exists. Replaced by the "controller" property.
+     * The controller device if one exists. Replaced by the "controller" property.
      *
      * Deprecated: 1.44
      **/
diff --git a/src/libnm-client-impl/nm-client.c b/src/libnm-client-impl/nm-client.c
index 1598fb30..4ecc8389 100644
--- a/src/libnm-client-impl/nm-client.c
+++ b/src/libnm-client-impl/nm-client.c
@@ -9221,17 +9221,17 @@ nm_client_wait_shutdown_finish(GAsyncResult *result, GError **error)
 
 /*****************************************************************************
  * Backported symbols. Usually, new API is only added in new major versions
- * of NetworkManager (that is, on "master" branch). Sometimes however, we might
+ * of NetworkManager (that is, on "main" branch). Sometimes however, we might
  * have to backport some API to an older stable branch. In that case, we backport
  * the symbols with a different version corresponding to the minor API.
  *
- * To allow upgrading from such a extended minor-release, "master" contains these
+ * To allow upgrading from such a extended minor-release, "main" contains these
  * backported symbols too.
  *
  * For example, 1.2.0 added nm_setting_connection_autoconnect_slaves_get_type.
  * This was backported for 1.0.4 as nm_setting_connection_autoconnect_slaves_get_type@libnm_1_0_4
  * To allow an application that was linked against 1.0.4 to seamlessly upgrade to
- * a newer major version, the same symbols is also exposed on "master". Note, that
+ * a newer major version, the same symbols is also exposed on "main". Note, that
  * a user can only seamlessly upgrade to a newer major version, that is released
  * *after* 1.0.4 is out. In this example, 1.2.0 was released after 1.4.0, and thus
  * a 1.0.4 user can upgrade to 1.2.0 ABI.
diff --git a/src/libnm-client-impl/nm-device-bond.c b/src/libnm-client-impl/nm-device-bond.c
index affcb993..9942c8de 100644
--- a/src/libnm-client-impl/nm-device-bond.c
+++ b/src/libnm-client-impl/nm-device-bond.c
@@ -76,7 +76,7 @@ nm_device_bond_get_carrier(NMDeviceBond *device)
  * nm_device_bond_get_slaves:
  * @device: a #NMDeviceBond
  *
- * Gets the devices currently enslaved to @device.
+ * Gets the devices currently attached as port to @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
  * #NMDevices that are slaves of @device. This is the internal
@@ -105,7 +105,7 @@ connection_compatible(NMDevice *device, NMConnection *connection, GError **error
         return FALSE;
     }
 
-    /* FIXME: check slaves? */
+    /* FIXME: check ports? */
 
     return TRUE;
 }
@@ -183,7 +183,7 @@ nm_device_bond_class_init(NMDeviceBondClass *klass)
     /**
      * NMDeviceBond:slaves: (type GPtrArray(NMDevice))
      *
-     * The devices enslaved to the bond device.
+     * The devices attached as port to the bond device.
      **/
     obj_properties[PROP_SLAVES] = g_param_spec_boxed(NM_DEVICE_BOND_SLAVES,
                                                      "",
@@ -193,5 +193,5 @@ nm_device_bond_class_init(NMDeviceBondClass *klass)
 
     _nml_dbus_meta_class_init_with_properties(object_class, &_nml_dbus_meta_iface_nm_device_bond);
 
-    device_class->slaves_param_spec = obj_properties[PROP_SLAVES];
+    device_class->ports_param_spec = obj_properties[PROP_SLAVES];
 }
diff --git a/src/libnm-client-impl/nm-libnm-utils.h b/src/libnm-client-impl/nm-libnm-utils.h
index 53fa36be..fddda077 100644
--- a/src/libnm-client-impl/nm-libnm-utils.h
+++ b/src/libnm-client-impl/nm-libnm-utils.h
@@ -852,7 +852,7 @@ struct _NMDeviceClass {
     /* Slaves was originally part of some subtypes of NMDevice. It was deprecated and
     * a new NMDevice::ports property was added. When that property changes, we need
     * to notify about the subclass' respective property. This is the property. */
-    const GParamSpec *slaves_param_spec;
+    const GParamSpec *ports_param_spec;
 };
 
 #define _NML_DEVICE_META_PROPERTY_INDEX_PORTS 27
diff --git a/src/libnm-client-impl/nm-device-bridge.c b/src/libnm-client-impl/nm-device-bridge.c
index abb78ced..8405a4ff 100644
--- a/src/libnm-client-impl/nm-device-bridge.c
+++ b/src/libnm-client-impl/nm-device-bridge.c
@@ -76,10 +76,10 @@ nm_device_bridge_get_carrier(NMDeviceBridge *device)
  * nm_device_bridge_get_slaves:
  * @device: a #NMDeviceBridge
  *
- * Gets the devices currently enslaved to @device.
+ * Gets the devices currently attached as port to @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
  * #NMDevices that are slaves of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
  * Deprecated: 1.34: Use nm_device_get_ports() instead.
@@ -188,7 +188,7 @@ nm_device_bridge_class_init(NMDeviceBridgeClass *klass)
     /**
      * NMDeviceBridge:slaves: (type GPtrArray(NMDevice))
      *
-     * The devices enslaved to the bridge device.
+     * The devices attached as port to the bridge device.
      **/
     obj_properties[PROP_SLAVES] = g_param_spec_boxed(NM_DEVICE_BRIDGE_SLAVES,
                                                      "",
@@ -198,5 +198,5 @@ nm_device_bridge_class_init(NMDeviceBridgeClass *klass)
 
     _nml_dbus_meta_class_init_with_properties(object_class, &_nml_dbus_meta_iface_nm_device_bridge);
 
-    device_class->slaves_param_spec = obj_properties[PROP_SLAVES];
+    device_class->ports_param_spec = obj_properties[PROP_SLAVES];
 }
@@ -76,10 +76,10 @@ nm_device_bridge_get_carrier(NMDeviceBridge *device)
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
- * #NMDevices that are slaves of @device. This is the internal
+ * #NMDevices that are ports of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
diff --git a/src/libnm-client-impl/nm-device-ovs-bridge.c b/src/libnm-client-impl/nm-device-ovs-bridge.c
index ef134798..56b76e90 100644
--- a/src/libnm-client-impl/nm-device-ovs-bridge.c
+++ b/src/libnm-client-impl/nm-device-ovs-bridge.c
@@ -36,10 +36,10 @@ G_DEFINE_TYPE(NMDeviceOvsBridge, nm_device_ovs_bridge, NM_TYPE_DEVICE)
  * nm_device_ovs_bridge_get_slaves:
  * @device: a #NMDeviceOvsBridge
  *
- * Gets the ports currently enslaved to @device.
+ * Gets the ports currently attached as port to @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
  * #NMDevices that are slaves of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
  * Since: 1.14
@@ -142,7 +142,7 @@ nm_device_ovs_bridge_class_init(NMDeviceOvsBridgeClass *klass)
     /**
      * NMDeviceOvsBridge:slaves: (type GPtrArray(NMDevice))
      *
-     * Gets the ports currently enslaved to the device.
+     * Gets the ports currently attached as port to the device.
      *
      * Since: 1.22
      */
@@ -155,5 +155,5 @@ nm_device_ovs_bridge_class_init(NMDeviceOvsBridgeClass *klass)
     _nml_dbus_meta_class_init_with_properties(object_class,
                                               &_nml_dbus_meta_iface_nm_device_ovsbridge);
 
-    device_class->slaves_param_spec = obj_properties[PROP_SLAVES];
+    device_class->ports_param_spec = obj_properties[PROP_SLAVES];
 }
@@ -36,10 +36,10 @@ G_DEFINE_TYPE(NMDeviceOvsBridge, nm_device_ovs_bridge, NM_TYPE_DEVICE)
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
- * #NMDevices that are slaves of @device. This is the internal
+ * #NMDevices that are ports of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
diff --git a/src/libnm-client-impl/nm-device-ovs-port.c b/src/libnm-client-impl/nm-device-ovs-port.c
index 5bcef73c..38e95231 100644
--- a/src/libnm-client-impl/nm-device-ovs-port.c
+++ b/src/libnm-client-impl/nm-device-ovs-port.c
@@ -36,10 +36,10 @@ G_DEFINE_TYPE(NMDeviceOvsPort, nm_device_ovs_port, NM_TYPE_DEVICE)
  * nm_device_ovs_port_get_slaves:
  * @device: a #NMDeviceOvsPort
  *
- * Gets the interfaces currently enslaved to @device.
+ * Gets the interfaces currently attached as port to @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
  * #NMDevices that are slaves of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
  * Since: 1.14
@@ -142,7 +142,7 @@ nm_device_ovs_port_class_init(NMDeviceOvsPortClass *klass)
     /**
      * NMDeviceOvsPort:slaves: (type GPtrArray(NMDevice))
      *
-     * Gets the interfaces currently enslaved to the device.
+     * Gets the interfaces currently attached as port to the device.
      *
      * Since: 1.22
      */
@@ -155,5 +155,5 @@ nm_device_ovs_port_class_init(NMDeviceOvsPortClass *klass)
     _nml_dbus_meta_class_init_with_properties(object_class,
                                               &_nml_dbus_meta_iface_nm_device_ovsport);
 
-    device_class->slaves_param_spec = obj_properties[PROP_SLAVES];
+    device_class->ports_param_spec = obj_properties[PROP_SLAVES];
 }
@@ -36,10 +36,10 @@ G_DEFINE_TYPE(NMDeviceOvsPort, nm_device_ovs_port, NM_TYPE_DEVICE)
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
- * #NMDevices that are slaves of @device. This is the internal
+ * #NMDevices that are ports of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
diff --git a/src/libnm-client-impl/nm-device-team.c b/src/libnm-client-impl/nm-device-team.c
index e0b21e8e..bf951ca1 100644
--- a/src/libnm-client-impl/nm-device-team.c
+++ b/src/libnm-client-impl/nm-device-team.c
@@ -77,10 +77,10 @@ nm_device_team_get_carrier(NMDeviceTeam *device)
  * nm_device_team_get_slaves:
  * @device: a #NMDeviceTeam
  *
- * Gets the devices currently enslaved to @device.
+ * Gets the devices currently attach as port to @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
  * #NMDevices that are slaves of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
  * Deprecated: 1.34: Use nm_device_get_ports() instead.
@@ -125,7 +125,7 @@ connection_compatible(NMDevice *device, NMConnection *connection, GError **error
         return FALSE;
     }
 
-    /* FIXME: check slaves? */
+    /* FIXME: check ports? */
 
     return TRUE;
 }
@@ -218,7 +218,7 @@ nm_device_team_class_init(NMDeviceTeamClass *klass)
     /**
      * NMDeviceTeam:slaves: (type GPtrArray(NMDevice))
      *
-     * The devices enslaved to the team device.
+     * The devices attached as port to the team device.
      **/
     obj_properties[PROP_SLAVES] = g_param_spec_boxed(NM_DEVICE_TEAM_SLAVES,
                                                      "",
@@ -241,5 +241,5 @@ nm_device_team_class_init(NMDeviceTeamClass *klass)
 
     _nml_dbus_meta_class_init_with_properties(object_class, &_nml_dbus_meta_iface_nm_device_team);
 
-    device_class->slaves_param_spec = obj_properties[PROP_SLAVES];
+    device_class->ports_param_spec = obj_properties[PROP_SLAVES];
 }
@@ -77,10 +77,10 @@ nm_device_team_get_carrier(NMDeviceTeam *device)
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing
- * #NMDevices that are slaves of @device. This is the internal
+ * #NMDevices that are ports of @device. This is the internal
  * copy used by the device, and must not be modified.
  *
diff --git a/src/libnm-client-impl/nm-device.c b/src/libnm-client-impl/nm-device.c
index 2d3be64c..dc868f5b 100644
--- a/src/libnm-client-impl/nm-device.c
+++ b/src/libnm-client-impl/nm-device.c
@@ -1283,7 +1283,7 @@ nm_device_get_type_description(NMDevice *device)
  * Gets the devices currently set as port of @device.
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing #NMDevices that
  * are slaves of @device. This is the internal copy used by the device and
  * must not be modified.
  *
  * Since: 1.34
@@ -1397,8 +1397,8 @@ _nm_device_notify_update_prop_ports(NMClient               *client,
     nm_assert(notify_update_prop_flags == NML_DBUS_NOTIFY_UPDATE_PROP_FLAGS_NOTIFY);
 
     klass = NM_DEVICE_GET_CLASS(self);
-    if (klass->slaves_param_spec)
-        _nm_client_queue_notify_object(client, self, klass->slaves_param_spec);
+    if (klass->ports_param_spec)
+        _nm_client_queue_notify_object(client, self, klass->ports_param_spec);
 out:
     return NML_DBUS_NOTIFY_UPDATE_PROP_FLAGS_NONE;
 }
@@ -1283,7 +1283,7 @@ nm_device_get_type_description(NMDevice *device)
  *
  * Returns: (element-type NMDevice): the #GPtrArray containing #NMDevices that
- * are slaves of @device. This is the internal copy used by the device and
+ * are ports of @device. This is the internal copy used by the device and
  * must not be modified.
  *